==> core-components-file-upload-item-6.1.1.tgz: package/esm/components/status-control/status-control.js <==
import { __assign } from 'tslib';
import React, { useContext, useRef } from 'react';
import cn from 'classnames';
import { SuperEllipse } from '@alfalab/core-components/icon-view/super-ellipse';
import { RADIUS, MAX_PROGRESS_BAR_VALUE } from '../../const/progress-bar.js';
import { FileUploadItemContext } from '../../context/file-upload-item-context.js';
import { isUploadingStatus, isSuccessStatus, isErrorStatus } from '../../utils.js';
import { StatusControlIcon } from './components/status-control-icon/status-control-icon.js';
import { StatusControlProgressBar } from './components/status-control-progress-bar/status-control-progress-bar.js';

var styles = {"container":"file-upload-item__container_16w5v","progress":"file-upload-item__progress_16w5v","uploading":"file-upload-item__uploading_16w5v","success":"file-upload-item__success_16w5v","error":"file-upload-item__error_16w5v","progressBarTransparent":"file-upload-item__progressBarTransparent_16w5v","progressBarUploading":"file-upload-item__progressBarUploading_16w5v","progressBarSuccess":"file-upload-item__progressBarSuccess_16w5v","progressBarError":"file-upload-item__progressBarError_16w5v"};
require('./status-control.css')

var StatusControl = function () {
    var _a, _b;
    var _c = useContext(FileUploadItemContext), _d = _c.uploadStatus, uploadStatus = _d === void 0 ? 'INITIAL' : _d, progressBar = _c.progressBar, imageUrl = _c.imageUrl;
    var progressRef = useRef(null);
    if (progressRef.current && progressBar) {
        progressRef.current.style.maskImage = "conic-gradient(red ".concat((RADIUS / MAX_PROGRESS_BAR_VALUE) * progressBar, "deg, transparent 0)");
    }
    var isTransparentProgressBar = function () {
        return uploadStatus === 'INITIAL' || uploadStatus === 'UPLOADED' || uploadStatus === 'DELETED';
    };
    return (React.createElement("div", { className: styles.container },
        React.createElement(SuperEllipse, __assign({ size: 48 }, (imageUrl && { imageUrl: imageUrl })),
            React.createElement(StatusControlIcon, null)),
        React.createElement("div", { ref: progressRef, className: cn(styles.progress, (_a = {},
                _a[styles.uploading] = isUploadingStatus(uploadStatus),
                _a[styles.success] = isSuccessStatus(uploadStatus),
                _a[styles.error] = isErrorStatus(uploadStatus),
                _a)) },
            React.createElement(StatusControlProgressBar, { className: cn((_b = {},
                    _b[styles.progressBarTransparent] = isTransparentProgressBar(),
                    _b[styles.progressBarUploading] = uploadStatus === 'UPLOADING',
                    _b[styles.progressBarSuccess] = uploadStatus === 'SUCCESS',
                    _b[styles.progressBarError] = uploadStatus === 'ERROR',
                    _b)) }))));
};

export { StatusControl };

==> core-components-file-upload-item-6.2.0.tgz: package/esm/components/status-control/status-control.js <==
import { __assign } from 'tslib';
import React, { useContext, useRef } from 'react';
import cn from 'classnames';
import { SuperEllipse } from '@alfalab/core-components/icon-view/super-ellipse';
import { RADIUS, MAX_PROGRESS_BAR_VALUE } from '../../const/progress-bar.js';
import { FileUploadItemContext } from '../../context/file-upload-item-context.js';
import { isUploadingStatus, isSuccessStatus, isErrorStatus } from '../../utils.js';
import { StatusControlIcon } from './components/status-control-icon/status-control-icon.js';
import { StatusControlProgressBar } from './components/status-control-progress-bar/status-control-progress-bar.js';

var styles = {"container":"file-upload-item__container_1oxte","progress":"file-upload-item__progress_1oxte","uploading":"file-upload-item__uploading_1oxte","success":"file-upload-item__success_1oxte","error":"file-upload-item__error_1oxte","progressBarTransparent":"file-upload-item__progressBarTransparent_1oxte","progressBarUploading":"file-upload-item__progressBarUploading_1oxte","progressBarSuccess":"file-upload-item__progressBarSuccess_1oxte","progressBarError":"file-upload-item__progressBarError_1oxte"};
require('./status-control.css')

var StatusControl = function () {
    var _a, _b;
    var _c = useContext(FileUploadItemContext), _d = _c.uploadStatus, uploadStatus = _d === void 0 ? 'INITIAL' : _d, progressBar = _c.progressBar, imageUrl = _c.imageUrl;
    var progressRef = useRef(null);
    if (progressRef.current && progressBar) {
        progressRef.current.style.maskImage = "conic-gradient(red ".concat((RADIUS / MAX_PROGRESS_BAR_VALUE) * progressBar, "deg, transparent 0)");
    }
    var isTransparentProgressBar = function () {
        return uploadStatus === 'INITIAL' || uploadStatus === 'UPLOADED' || uploadStatus === 'DELETED';
    };
    return (React.createElement("div", { className: styles.container },
        React.createElement(SuperEllipse, __assign({ size: 48 }, (imageUrl && { imageUrl: imageUrl })),
            React.createElement(StatusControlIcon, null)),
        React.createElement("div", { ref: progressRef, className: cn(styles.progress, (_a = {},
                _a[styles.uploading] = isUploadingStatus(uploadStatus),
                _a[styles.success] = isSuccessStatus(uploadStatus),
                _a[styles.error] = isErrorStatus(uploadStatus),
                _a)) },
            React.createElement(StatusControlProgressBar, { className: cn((_b = {},
                    _b[styles.progressBarTransparent] = isTransparentProgressBar(),
                    _b[styles.progressBarUploading] = uploadStatus === 'UPLOADING',
                    _b[styles.progressBarSuccess] = uploadStatus === 'SUCCESS',
                    _b[styles.progressBarError] = uploadStatus === 'ERROR',
                    _b)) }))));
};

export { StatusControl };
